@@ -14,7 +14,7 @@ class Plugin(NamedTuple):
     qgis_minimum_version: str = None
     qgis_maximum_version: str = None
     homepage: str = None
-    prerelease: str = None
+    pre_release: str = None
     file_name: str = None
     icon: str = None
     author_name: str = None
@@ -29,11 +29,12 @@ class Plugin(NamedTuple):
     tags: str = None
     server: bool = False
     has_processing: bool = False
+    has_wps: bool = False
 
 
 class Level:
     """ Color in terminal. """
     Success = '\033[92m'
-    Warning = '\033[93m'
+    Alert = '\033[93m'
     Critical = '\033[91m'
     End = '\033[0m'
