@@ -4,7 +4,6 @@ __email__ = 'info@3liz.org'
 
 import configparser
 import os
-import pwd
 import shutil
 import stat
 
@@ -201,14 +200,19 @@ class LocalDirectory:
 
         return False
 
-    def print_table(self):  # noqa: C901
+    def print_table(self, current_directory: bool = True):  # noqa: C901
         """ Print all plugins installed as a table. """
         if self._plugins is None:
             self.plugin_list()
 
         remote = Remote(self.folder, qgis_version=self.qgis_version_str)
 
-        print(f"List all plugins in {self.folder.absolute()}\n")
+        if current_directory:
+            print(f"List all plugins in the current working directory : {self.folder.absolute()}\n")
+        else:
+            print(
+                f"List all plugins in the directory set by environment variable : {self.folder.absolute()}\n")
+
         headers = [
             'Folder ⬇', 'Name', 'Version', 'Flags', 'QGIS min', 'QGIS max', 'Author',
             'Folder rights', 'Action ⚠',
@@ -263,8 +267,13 @@ class LocalDirectory:
             perms = stat.S_IMODE(os.stat(folder).st_mode)
             user_info = stat_info.st_uid
             try:
-                user_name = pwd.getpwuid(user_info)[0]
-            except KeyError:
+                import pwd
+                try:
+                    user_name = pwd.getpwuid(user_info)[0]
+                except KeyError:
+                    user_name = user_info
+            except ModuleNotFoundError:
+                # On Windows, pwd does not exist
                 user_name = user_info
             permissions = f"{user_name} : {oct(perms)}"
             plugin_data.append(permissions)
